Index: /trunk/include/VBox/GuestHost/SharedClipboard-win.h
===================================================================
--- /trunk/include/VBox/GuestHost/SharedClipboard-win.h	(revision 83623)
+++ /trunk/include/VBox/GuestHost/SharedClipboard-win.h	(revision 83624)
@@ -135,5 +135,5 @@
 
 SHCLFORMAT SharedClipboardWinClipboardFormatToVBox(UINT uFormat);
-int SharedClipboardWinGetFormats(PSHCLWINCTX pCtx, PSHCLFORMATDATA pFormats);
+int SharedClipboardWinGetFormats(PSHCLWINCTX pCtx, PSHCLFORMATS pfFormats);
 
 #ifdef VBOX_WITH_SHARED_CLIPBOARD_TRANSFERS
Index: /trunk/include/VBox/GuestHost/SharedClipboard.h
===================================================================
--- /trunk/include/VBox/GuestHost/SharedClipboard.h	(revision 83623)
+++ /trunk/include/VBox/GuestHost/SharedClipboard.h	(revision 83624)
@@ -76,20 +76,4 @@
 /** Pointer to a shared clipboard data request. */
 typedef SHCLDATAREQ *PSHCLDATAREQ;
-
-/**
- * Shared Clipboard formats specification.
- * @todo r=bird: Pointless as we don't have any fFlags defined, so, unless
- *       someone can give me a plausible scenario where we will need flags here,
- *       this structure will be eliminated.
- */
-typedef struct SHCLFORMATDATA
-{
-    /** Available format(s) as bit map. */
-    SHCLFORMATS Formats;
-    /** Formats flags. Currently unused. */
-    uint32_t    fFlags;
-} SHCLFORMATDATA;
-/** Pointer to a shared clipboard formats specification. */
-typedef SHCLFORMATDATA *PSHCLFORMATDATA;
 
 /**
Index: /trunk/include/VBox/VBoxGuestLib.h
===================================================================
--- /trunk/include/VBox/VBoxGuestLib.h	(revision 83623)
+++ /trunk/include/VBox/VBoxGuestLib.h	(revision 83624)
@@ -656,5 +656,5 @@
     {
         /** Reports available formats from the host. */
-        SHCLFORMATDATA       ReportedFormats;
+        SHCLFORMATS          fReportedFormats;
         /** Reports that data needs to be read from the guest. */
         SHCLFORMAT           fReadData;
Index: /trunk/src/VBox/Additions/WINNT/VBoxTray/VBoxClipboard.cpp
===================================================================
--- /trunk/src/VBox/Additions/WINNT/VBoxTray/VBoxClipboard.cpp	(revision 83623)
+++ /trunk/src/VBox/Additions/WINNT/VBoxTray/VBoxClipboard.cpp	(revision 83624)
@@ -256,10 +256,10 @@
                     /* Clipboard was updated by another application.
                      * Report available formats to the host. */
-                    SHCLFORMATDATA Formats;
-                    int rc = SharedClipboardWinGetFormats(pWinCtx, &Formats);
+                    SHCLFORMATS fFormats;
+                    int rc = SharedClipboardWinGetFormats(pWinCtx, &fFormats);
                     if (RT_SUCCESS(rc))
                     {
-                        LogFunc(("WM_CLIPBOARDUPDATE: Reporting formats %#x\n", Formats.Formats));
-                        rc = VbglR3ClipboardReportFormats(pCtx->CmdCtx.idClient, Formats.Formats);
+                        LogFunc(("WM_CLIPBOARDUPDATE: Reporting formats %#x\n", fFormats));
+                        rc = VbglR3ClipboardReportFormats(pCtx->CmdCtx.idClient, fFormats);
                     }
                 }
@@ -303,9 +303,9 @@
                     /* Clipboard was updated by another application. */
                     /* WM_DRAWCLIPBOARD always expects a return code of 0, so don't change "rc" here. */
-                    SHCLFORMATDATA Formats;
-                    rc = SharedClipboardWinGetFormats(pWinCtx, &Formats);
+                    SHCLFORMATS fFormats;
+                    rc = SharedClipboardWinGetFormats(pWinCtx, &fFormats);
                     if (   RT_SUCCESS(rc)
-                        && Formats.Formats != VBOX_SHCL_FMT_NONE)
-                        rc = VbglR3ClipboardReportFormats(pCtx->CmdCtx.idClient, Formats.Formats);
+                        && fFormats != VBOX_SHCL_FMT_NONE)
+                        rc = VbglR3ClipboardReportFormats(pCtx->CmdCtx.idClient, fFormats);
                 }
                 else
@@ -506,5 +506,5 @@
             Assert(pEvent->enmType == VBGLR3CLIPBOARDEVENTTYPE_REPORT_FORMATS);
 
-            const SHCLFORMATS fFormats = pEvent->u.ReportedFormats.Formats;
+            const SHCLFORMATS fFormats = pEvent->u.fReportedFormats;
 
             if (fFormats != VBOX_SHCL_FMT_NONE) /* Could arrive with some older GA versions. */
Index: /trunk/src/VBox/Additions/x11/VBoxClient/clipboard.cpp
===================================================================
--- /trunk/src/VBox/Additions/x11/VBoxClient/clipboard.cpp	(revision 83623)
+++ /trunk/src/VBox/Additions/x11/VBoxClient/clipboard.cpp	(revision 83624)
@@ -303,5 +303,5 @@
                 case VBGLR3CLIPBOARDEVENTTYPE_REPORT_FORMATS:
                 {
-                    ShClX11ReportFormatsToX11(&g_Ctx.X11, pEvent->u.ReportedFormats.Formats);
+                    ShClX11ReportFormatsToX11(&g_Ctx.X11, pEvent->u.fReportedFormats);
                     break;
                 }
Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-internal.h
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-internal.h	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-internal.h	(revision 83624)
@@ -282,8 +282,8 @@
  * @returns VBox status code.
  * @param   pClient             Shared Clipboard client context.
- * @param   pCmdCtx             Shared Clipboard command context.
- * @param   pFormats            Announced formats from the guest.
- */
-int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx, PSHCLFORMATDATA pFormats);
+ * @param   fFormats            The announced formats from the guest,
+ *                              VBOX_SHCL_FMT_XXX.
+ */
+int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, SHCLFORMATS fFormats);
 /** @todo Document: Can return VINF_HGCM_ASYNC_EXECUTE to defer returning read data.*/
 /**
Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-win.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-win.cpp	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-win.cpp	(revision 83624)
@@ -573,11 +573,9 @@
     if (pCtx->pClient)
     {
-        SHCLFORMATDATA Formats;
-        RT_ZERO(Formats);
-
-        rc = SharedClipboardWinGetFormats(&pCtx->Win, &Formats);
+        SHCLFORMATS fFormats = 0;
+        rc = SharedClipboardWinGetFormats(&pCtx->Win, &fFormats);
         if (   RT_SUCCESS(rc)
-            && Formats.Formats != VBOX_SHCL_FMT_NONE) /** @todo r=bird: BUGBUG: revisit this. */
-            rc = ShClSvcHostReportFormats(pCtx->pClient, Formats.Formats);
+            && fFormats != VBOX_SHCL_FMT_NONE) /** @todo r=bird: BUGBUG: revisit this. */
+            rc = ShClSvcHostReportFormats(pCtx->pClient, fFormats);
     }
     else /* If we don't have any client data (yet), bail out. */
@@ -696,16 +694,12 @@
 }
 
-int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx,
-                              PSHCLFORMATDATA pFormats)
+int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, SHCLFORMATS fFormats)
 {
     AssertPtrReturn(pClient, VERR_INVALID_POINTER);
-    RT_NOREF(pCmdCtx);
-
-    int rc;
 
     PSHCLCONTEXT pCtx = pClient->State.pCtx;
     AssertPtrReturn(pCtx, VERR_INVALID_POINTER);
 
-    LogFlowFunc(("uFormats=0x%x, hWnd=%p\n", pFormats->Formats, pCtx->Win.hWnd));
+    LogFlowFunc(("fFormats=0x%x, hWnd=%p\n", fFormats, pCtx->Win.hWnd));
 
     /*
@@ -713,10 +707,9 @@
      */
     PostMessage(pCtx->Win.hWnd, SHCL_WIN_WM_REPORT_FORMATS,
-                0 /* wParam */, pFormats->Formats /* lParam */);
-
-    rc = VINF_SUCCESS;
-
-    LogFlowFuncLeaveRC(rc);
-    return rc;
+                0 /* wParam */, fFormats /* lParam */);
+
+
+    LogFlowFuncLeaveRC(VINF_SUCCESS);
+    return VINF_SUCCESS;
 }
 
Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-x11.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-x11.cpp	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-x11.cpp	(revision 83624)
@@ -146,10 +146,7 @@
 }
 
-int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx,
-                              PSHCLFORMATDATA pFormats)
-{
-    RT_NOREF(pCmdCtx);
-
-    int rc = ShClX11ReportFormatsToX11(&pClient->State.pCtx->X11, pFormats->Formats);
+int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, SHCLFORMATS fFormats)
+{
+    int rc = ShClX11ReportFormatsToX11(&pClient->State.pCtx->X11, fFormats);
 
     LogFlowFuncLeaveRC(rc);
Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc.cpp	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc.cpp	(revision 83624)
@@ -1464,13 +1464,5 @@
             }
             else
-            {
-                SHCLCLIENTCMDCTX CmdCtx;
-                RT_ZERO(CmdCtx);
-
-                SHCLFORMATDATA FormatData;
-                FormatData.fFlags  = 0;
-                FormatData.Formats = fFormats;
-                rc = ShClSvcImplFormatAnnounce(pClient, &CmdCtx, &FormatData);
-            }
+                rc = ShClSvcImplFormatAnnounce(pClient, fFormats);
         }
     }
Index: /trunk/src/VBox/HostServices/SharedClipboard/testcase/tstClipboardServiceHost.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/testcase/tstClipboardServiceHost.cpp	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/testcase/tstClipboardServiceHost.cpp	(revision 83624)
@@ -312,5 +312,5 @@
 int ShClSvcImplDisconnect(PSHCLCLIENT) { return VINF_SUCCESS; }
 int ShClSvcImplConnect(PSHCLCLIENT, bool) { return VINF_SUCCESS; }
-int ShClSvcImplFormatAnnounce(PSHCLCLIENT, PSHCLCLIENTCMDCTX, PSHCLFORMATDATA) { AssertFailed(); return VINF_SUCCESS; }
+int ShClSvcImplFormatAnnounce(PSHCLCLIENT, SHCLFORMATS) { AssertFailed(); return VINF_SUCCESS; }
 int ShClSvcImplReadData(PSHCLCLIENT, PSHCLCLIENTCMDCTX, SHCLFORMAT, void *, uint32_t, unsigned int *) { AssertFailed(); return VERR_WRONG_ORDER; }
 int ShClSvcImplWriteData(PSHCLCLIENT, PSHCLCLIENTCMDCTX, SHCLFORMAT, void *, uint32_t) { AssertFailed(); return VINF_SUCCESS; }

Index: /trunk/src/VBox/Additions/common/VBoxGuest/lib/VBoxGuestR3LibClipboard.cpp
===================================================================
--- /trunk/src/VBox/Additions/common/VBoxGuest/lib/VBoxGuestR3LibClipboard.cpp	(revision 83623)
+++ /trunk/src/VBox/Additions/common/VBoxGuest/lib/VBoxGuestR3LibClipboard.cpp	(revision 83624)
@@ -253,14 +253,14 @@
  *
  * @returns VBox status code.
- * @param   pCtx                Shared Clipboard command context to use for the connection.
- * @param   pFormats            Where to store the received formats from the host.
- */
-static int vbglR3ClipboardFormatsReportRecv(PVBGLR3SHCLCMDCTX pCtx, PSHCLFORMATDATA pFormats)
-{
-    AssertPtrReturn(pCtx,     VERR_INVALID_POINTER);
-    AssertPtrReturn(pFormats, VERR_INVALID_POINTER);
-
-    pFormats->fFlags = 0;
-    pFormats->Formats = 0;
+ * @param   pCtx        Shared Clipboard command context to use for the
+ *                      connection.
+ * @param   pfFormats   Where to store the received formats from the host.
+ */
+static int vbglR3ClipboardFormatsReportRecv(PVBGLR3SHCLCMDCTX pCtx, PSHCLFORMATS pfFormats)
+{
+    AssertPtrReturn(pCtx, VERR_INVALID_POINTER);
+    AssertPtrReturn(pfFormats, VERR_INVALID_POINTER);
+
+    *pfFormats = 0;
 
     struct
@@ -278,5 +278,5 @@
     if (RT_SUCCESS(rc))
     {
-        rc = Msg.f32Formats.GetUInt32(&pFormats->Formats);
+        rc = Msg.f32Formats.GetUInt32(pfFormats);
         AssertRC(rc);
     }
@@ -2332,5 +2332,5 @@
             case VBOX_SHCL_HOST_MSG_FORMATS_REPORT:
                 pEvent->enmType = VBGLR3CLIPBOARDEVENTTYPE_REPORT_FORMATS;
-                pEvent->u.ReportedFormats.Formats = cParms;
+                pEvent->u.fReportedFormats = cParms;
                 break;
 
@@ -2372,5 +2372,5 @@
             case VBOX_SHCL_HOST_MSG_FORMATS_REPORT:
             {
-                rc = vbglR3ClipboardFormatsReportRecv(pCtx, &pEvent->u.ReportedFormats);
+                rc = vbglR3ClipboardFormatsReportRecv(pCtx, &pEvent->u.fReportedFormats);
                 if (RT_SUCCESS(rc))
                     pEvent->enmType = VBGLR3CLIPBOARDEVENTTYPE_REPORT_FORMATS;
@@ -2432,5 +2432,5 @@
             case VBOX_SHCL_HOST_MSG_FORMATS_REPORT:
                 pEvent->enmType = VBGLR3CLIPBOARDEVENTTYPE_REPORT_FORMATS;
-                pEvent->u.ReportedFormats.Formats = cParms;
+                pEvent->u.fReportedFormats = cParms;
                 break;
 
Index: /trunk/src/VBox/GuestHost/SharedClipboard/clipboard-win.cpp
===================================================================
--- /trunk/src/VBox/GuestHost/SharedClipboard/clipboard-win.cpp	(revision 83623)
+++ /trunk/src/VBox/GuestHost/SharedClipboard/clipboard-win.cpp	(revision 83624)
@@ -420,10 +420,10 @@
  * @returns VBox status code.
  * @param   pCtx                Windows clipboard context to retrieve formats for.
- * @param   pFormats            Where to store the retrieved formats.
- */
-int SharedClipboardWinGetFormats(PSHCLWINCTX pCtx, PSHCLFORMATDATA pFormats)
-{
-    AssertPtrReturn(pCtx,     VERR_INVALID_POINTER);
-    AssertPtrReturn(pFormats, VERR_INVALID_POINTER);
+ * @param   pfFormats           Where to store the retrieved formats.
+ */
+int SharedClipboardWinGetFormats(PSHCLWINCTX pCtx, PSHCLFORMATS pfFormats)
+{
+    AssertPtrReturn(pCtx, VERR_INVALID_POINTER);
+    AssertPtrReturn(pfFormats, VERR_INVALID_POINTER);
 
     SHCLFORMATS fFormats = VBOX_SHCL_FMT_NONE;
@@ -439,18 +439,10 @@
         int rc2 = SharedClipboardWinClose();
         AssertRC(rc2);
-    }
-
-    if (RT_FAILURE(rc))
-    {
-        LogFunc(("Failed with rc=%Rrc\n", rc));
+        LogFlowFunc(("fFormats=%#x\n", fFormats));
     }
     else
-    {
-        LogFlowFunc(("fFormats=0x%08X\n", fFormats));
-
-        pFormats->Formats = fFormats;
-        pFormats->fFlags   = 0; /** @todo Handle flags. */
-    }
-
+        LogFunc(("Failed with rc=%Rrc (fFormats=%#x)\n", rc, fFormats));
+
+    *pfFormats = fFormats;
     return rc;
 }
Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-darwin.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-darwin.cpp	(revision 83623)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxSharedClipboardSvc-darwin.cpp	(revision 83624)
@@ -35,13 +35,15 @@
 *********************************************************************************************************************************/
 /** Global clipboard context information */
-struct SHCLCONTEXT
-{
-    /** We have a separate thread to poll for new clipboard content */
-    RTTHREAD                thread;
+typedef struct SHCLCONTEXT
+{
+    /** We have a separate thread to poll for new clipboard content. */
+    RTTHREAD                hThread;
+    /** Termination indicator.   */
     bool volatile           fTerminate;
     /** The reference to the current pasteboard */
-    PasteboardRef           pasteboard;
-    PSHCLCLIENT    pClient;
-};
+    PasteboardRef           hPasteboard;
+    /** Shared clipboard client. */
+    PSHCLCLIENT             pClient;
+} SHCLCONTEXT;
 
 
@@ -67,5 +69,5 @@
     bool fChanged = false;
     /* Retrieve the formats currently in the clipboard and supported by vbox */
-    int rc = queryNewPasteboardFormats(pCtx->pasteboard, &fFormats, &fChanged);
+    int rc = queryNewPasteboardFormats(pCtx->hPasteboard, &fFormats, &fChanged);
     if (   RT_SUCCESS(rc)
         && fChanged)
@@ -77,19 +79,13 @@
 
 /**
- * The poller thread.
+ * @callback_method_impl{FNRTTHREAD, The poller thread.
  *
- * This thread will check for the arrival of new data on the clipboard.
- *
- * @returns VINF_SUCCESS (not used).
- * @param   ThreadSelf  Our thread handle.
- * @param   pvUser      Pointer to the SHCLCONTEXT structure.
- *
- */
-static int vboxClipboardThread(RTTHREAD ThreadSelf, void *pvUser)
-{
+ * This thread will check for the arrival of new data on the clipboard.}
+ */
+static DECLCALLBACK(int) vboxClipboardThread(RTTHREAD ThreadSelf, void *pvUser)
+{
+    SHCLCONTEXT *pCtx = (SHCLCONTEXT *)pvUser;
+    AssertPtr(pCtx);
     LogFlowFuncEnter();
-
-    AssertPtrReturn(pvUser, VERR_INVALID_PARAMETER);
-    SHCLCONTEXT *pCtx = (SHCLCONTEXT *)pvUser;
 
     while (!pCtx->fTerminate)
@@ -114,13 +110,13 @@
     g_ctx.fTerminate = false;
 
-    int rc = initPasteboard(&g_ctx.pasteboard);
+    int rc = initPasteboard(&g_ctx.hPasteboard);
     AssertRCReturn(rc, rc);
 
-    rc = RTThreadCreate(&g_ctx.thread, vboxClipboardThread, &g_ctx, 0,
+    rc = RTThreadCreate(&g_ctx.hThread, vboxClipboardThread, &g_ctx, 0,
                         RTTHREADTYPE_IO, RTTHREADFLAGS_WAITABLE, "SHCLIP");
     if (RT_FAILURE(rc))
     {
-        g_ctx.thread = NIL_RTTHREAD;
-        destroyPasteboard(&g_ctx.pasteboard);
+        g_ctx.hThread = NIL_RTTHREAD;
+        destroyPasteboard(&g_ctx.hPasteboard);
     }
 
@@ -134,14 +130,14 @@
      */
     ASMAtomicWriteBool(&g_ctx.fTerminate, true);
-    int rc = RTThreadUserSignal(g_ctx.thread);
+    int rc = RTThreadUserSignal(g_ctx.hThread);
     AssertRC(rc);
-    rc = RTThreadWait(g_ctx.thread, RT_INDEFINITE_WAIT, NULL);
+    rc = RTThreadWait(g_ctx.hThread, RT_INDEFINITE_WAIT, NULL);
     AssertRC(rc);
 
     /*
      * Destroy the pasteboard and uninitialize the global context record.
      */
-    destroyPasteboard(&g_ctx.pasteboard);
-    g_ctx.thread = NIL_RTTHREAD;
+    destroyPasteboard(&g_ctx.hPasteboard);
+    g_ctx.hThread = NIL_RTTHREAD;
     g_ctx.pClient = NULL;
 }
@@ -190,12 +186,9 @@
 }
 
-int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient,
-                              PSHCLCLIENTCMDCTX pCmdCtx, PSHCLFORMATDATA pFormats)
-{
-    RT_NOREF(pCmdCtx);
-
-    LogFlowFunc(("uFormats=%02X\n", pFormats->Formats));
-
-    if (pFormats->Formats == VBOX_SHCL_FMT_NONE)
+int ShClSvcImplFormatAnnounce(PSHCLCLIENT pClient, SHCLFORMATS fFormats)
+{
+    LogFlowFunc(("fFormats=%02X\n", fFormats));
+
+    if (fFormats == VBOX_SHCL_FMT_NONE)
     {
         /* This is just an automatism, not a genuine announcement */
@@ -204,13 +197,13 @@
 
 #ifdef VBOX_WITH_SHARED_CLIPBOARD_TRANSFERS
-    if (pFormats->Formats & VBOX_SHCL_FMT_URI_LIST) /* No transfer support yet. */
+    if (fFormats & VBOX_SHCL_FMT_URI_LIST) /* No transfer support yet. */
         return VINF_SUCCESS;
 #endif
 
-    return ShClSvcDataReadRequest(pClient, pFormats->Formats, NULL /* pidEvent */);
-}
-
-int ShClSvcImplReadData(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx,
-                        SHCLFORMAT uFormat, void *pvData, uint32_t cbData, uint32_t *pcbActual)
+    return ShClSvcDataReadRequest(pClient, fFormats, NULL /* pidEvent */);
+}
+
+int ShClSvcImplReadData(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx, SHCLFORMAT fFormat,
+                        void *pvData, uint32_t cbData, uint32_t *pcbActual)
 {
     RT_NOREF(pCmdCtx);
@@ -221,14 +214,12 @@
     *pcbActual = 0;
 
-    int rc = readFromPasteboard(pClient->State.pCtx->pasteboard,
-                                uFormat, pvData, cbData, pcbActual);
-
-    ShClSvcUnlock();
-
-    return rc;
-}
-
-int ShClSvcImplWriteData(PSHCLCLIENT pClient,
-                         PSHCLCLIENTCMDCTX pCmdCtx, SHCLFORMAT uFormat, void *pvData, uint32_t cbData)
+    int rc = readFromPasteboard(pClient->State.pCtx->hPasteboard, fFormat, pvData, cbData, pcbActual);
+
+    ShClSvcUnlock();
+
+    return rc;
+}
+
+int ShClSvcImplWriteData(PSHCLCLIENT pClient, PSHCLCLIENTCMDCTX pCmdCtx, SHCLFORMAT fFormat, void *pvData, uint32_t cbData)
 {
     RT_NOREF(pCmdCtx);
@@ -236,5 +227,5 @@
     ShClSvcLock();
 
-    writeToPasteboard(pClient->State.pCtx->pasteboard, pvData, cbData, uFormat);
+    writeToPasteboard(pClient->State.pCtx->hPasteboard, pvData, cbData, fFormat);
 
     ShClSvcUnlock();
@@ -244,4 +235,5 @@
 
 #ifdef VBOX_WITH_SHARED_CLIPBOARD_TRANSFERS
+
 int ShClSvcImplTransferReadDir(PSHCLCLIENT pClient, PSHCLDIRDATA pDirData)
 {
@@ -279,4 +271,5 @@
     return VERR_NOT_IMPLEMENTED;
 }
+
 #endif /* VBOX_WITH_SHARED_CLIPBOARD_TRANSFERS */
 
@@ -134,14 +130,14 @@
 
     /*
-     * Destroy the pasteboard and uninitialize the global context record.
+     * Destroy the hPasteboard and uninitialize the global context record.
      */